# Overview

Interface for the PlentyMarkets API.

# Setup

## Requirements

* Python 3.7.8+

## Installation

Install it directly into an activated virtual environment:

```text
$ pip install python_plenty_api
```

or add it to your [Poetry](https://poetry.eustace.io/) project:

```text
$ poetry add python_plenty_api
```

# Usage

After installation, the package can imported:

```text
$ python
>>> import plenty_api
>>> plenty_api.__version__
```
